/*
 * Syncdaemon API
 *
 * Authors: Rodrigo Moya <rodrigo.moya@canonical.com>
 *
 * Copyright 2010 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3, as published
 * by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranties of
 * MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef __SYNCDAEMON_AUTHENTICATION_H__
#define __SYNCDAEMON_AUTHENTICATION_H__

#include <glib-object.h>
#include "syncdaemon-credentials.h"

G_BEGIN_DECLS

#define SYNCDAEMON_TYPE_AUTHENTICATION                (syncdaemon_authentication_get_type ())
#define SYNCDAEMON_AUTHENTICATION(obj)                (G_TYPE_CHECK_INSTANCE_CAST ((obj), SYNCDAEMON_TYPE_AUTHENTICATION, SyncdaemonAuthentication))
#define SYNCDAEMON_IS_AUTHENTICATION(obj)             (G_TYPE_CHECK_INSTANCE_TYPE ((obj), SYNCDAEMON_TYPE_AUTHENTICATION))
#define SYNCDAEMON_AUTHENTICATION_CLASS(klass)        (G_TYPE_CHECK_CLASS_CAST ((klass), SYNCDAEMON_TYPE_AUTHENTICATION, SyncdaemonAuthenticationClass))
#define SYNCDAEMON_IS_AUTHENTICATION_CLASS(klass)     (G_TYPE_CHECK_CLASS_TYPE ((klass), SYNCDAEMON_TYPE_AUTHENTICATION))
#define SYNCDAEMON_AUTHENTICATION_GET_CLASS(obj)      (G_TYPE_INSTANCE_GET_CLASS ((obj), SYNCDAEMON_TYPE_AUTHENTICATION, SyncdaemonAuthenticationClass))

typedef struct _SyncdaemonAuthenticationPrivate SyncdaemonAuthenticationPrivate;

typedef struct {
	GObject parent;
	SyncdaemonAuthenticationPrivate *priv;
} SyncdaemonAuthentication;

typedef struct {
	GObjectClass parent_class;

	void (* credentials_found) (SyncdaemonAuthentication *auth, SyncdaemonCredentials *credentials);
	void (* authorization_cancelled) (SyncdaemonAuthentication *auth);
	void (* error) (SyncdaemonAuthentication *auth, const gchar *error);
} SyncdaemonAuthenticationClass;

GType                     syncdaemon_authentication_get_type (void);
SyncdaemonAuthentication *syncdaemon_authentication_new (void);

SyncdaemonCredentials    *syncdaemon_authentication_find_credentials (SyncdaemonAuthentication *auth);
gboolean                  syncdaemon_authentication_has_credentials (SyncdaemonAuthentication *auth);
void                      syncdaemon_authentication_login_or_register (SyncdaemonAuthentication *auth);
void                      syncdaemon_authentication_clear_token (SyncdaemonAuthentication *auth);

G_END_DECLS

#endif
